#!/usr/bin/bash
#########################################################################################################
# iDoctor 
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2000, 2014 All Rights Reserved.
#########################################################################################################
# This script will collect general information about a set of NMON collections 
# All NMON collections found on the system are the symbolic links residing in directory is /tmp/idoctor/nmon
# In order for a NMON collection to be visible to iDoctor a symbolic link must be created using commands like:
# 	 cd /tmp/idoctor/nmon
#        ln -s /tmp/nmon/nmondata.nmon nmondata.nmon

# parses data from the nmon file
getnmoninfo() {
    awk ' 
	 BEGIN { FS="," } 
        /AAA,date,/ { snapdate=$3 } 
        /AAA,time,/ { snaptime=$3 } 
	/AAA,command,/ {cmd=$3 }   
        /AAA,host,/ { pname=$3 } 
	END {	
	    printf("%s,%s %s,%s\n",
                pname, snapdate, snaptime, cmd);  
        }'
}

########################
# Main()
########################
BASEDIR=$(dirname $0)	# This will get the directory this script resides in
#prints the column header
echo "File, Location, Partition collected on, Time, Command Used"
host_name=$(hostname -s)	
mkdir -p $BASEDIR/repository/nmon
find $BASEDIR/repository/nmon/ -type l | while read nmonfile
do    	
	if [ -f "$nmonfile" ]; then # If file exists
		out=`cat $nmonfile | getnmoninfo`
		deref=`ls -l $nmonfile | awk '{printf $9}'`
		printf "%s,%s,%s\n" "$deref" "$host_name" "$out" 
	else
		rm $nmonfile
	fi
done