#!/bin/ksh93
#########################################################################################################
# iDoctor VIOS Investigator
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2000, 2013 All Rights Reserved.
#########################################################################################################
# This script will collect general information about a set of vios_advisor collections (developerworks version)
# All collections found on the system are the symbolic links residing in directory is /tmp/idoctor/advisor
# In order for a VIOS Advisor collection to be visible to iDoctor a symbolic link must be created using commands like:
# 	 cd /tmp/idoctor/advisor
#        ln -s /tmp/advisor/vios_advisor123.xml vios_advisor.xml

# parses data from the vios_advisor XML file
getadvisorinfo() {
 /usr/bin/awk ' 
       BEGIN  { FS="," } 
            /HostName/ { pname=$0 }
            /version/ { ver=$0 }
            /Duration/ { duration=$0 }

       END {
            pname=substr(pname, index(pname, ">") +1);
            pname=substr(pname, 1, index(pname, "<") - 1);

            ver=substr(ver, index(ver, "version") +9, 7);
          
            duration=substr(duration, index(duration, ">") +1);
            duration=substr(duration, 1, index(duration, "<") - 1);

            printf("%s,%s,%s", pname, ver, duration);  
        }' 
}

getcurinterval() {
    /usr/bin/awk 'BEGIN {FS=","} {print $1}' 
}


getmaxinterval() {
     /usr/bin/awk ' {
          nSnaps=substr($0,282,10);
          gsub(/^[ \t]+|[ \t]+$nSnaps/, "", nSnaps); 
          printf("%s", nSnaps);  
       }     '
}
	
########################
# Main()
########################
BASEDIR=$(dirname $0)	# This will get the directory this script resides in

#prints the column header
print "File, Location\n"
host_name=$(/usr/bin/hostname -s)
mkdir -p $BASEDIR/repository/advisor
find $BASEDIR/repository/advisor/ -type l | while read advisorfile
do    	
            if [[ -f "$advisorfile" ]] then # If file exists
	      printf "%s,%s \n" "$advisorfile" "$host_name"  
            else
	       rm $advisorfile
	fi
done