#!/bin/ksh93
#########################################################################################################
# iDoctor VIOS Investigator
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2000, 2012 All Rights Reserved.
#########################################################################################################
# This script will collect general information about a set of NMON collections 
# All NMON collections found on the system are the symbolic links residing in directory is /tmp/idoctor/nmon
# In order for a NMON collection to be visible to iDoctor a symbolic link must be created using commands like:
# 	 cd /tmp/idoctor/nmon
#        ln -s /tmp/nmon/nmondata.nmon nmondata.nmon

# parses data from the nmon file
getnmoninfo() {
    /usr/bin/awk ' 
	 BEGIN { FS="," } 
        /AAA,date,/ { snapdate=$3 } 
        /AAA,time,/ { snaptime=$3 } 
	/AAA,command,/ {cmd=$3 }   
        /AAA,host,/ { pname=$3 } 
	/AAA,LPARNumberName,/ { pnum=$3} 
	/Type                                       :/ { ptype=$4 }
	/Mode                                       :/ { pmode=$4 }
	/Entitled Capacity                          :/ { ec=$4 }
	/Online Virtual CPUs                        :/ { vcpus=$4 }
	/Online Memory                              :/ { vmem=$4 }
	/Variable Capacity Weight                   :/ { vcw=$4 }
	END {
	    ptype=substr(ptype, index(ptype, ":") +1);
	    ptype=substr(ptype, 1, index(ptype, "\"") - 1);
	    pmode=substr(pmode, index(pmode, ":") +1);
	    pmode=substr(pmode, 1, index(pmode, "\"") - 1);
	    ec=substr(ec, index(ec, ":") +1);
	    ec=substr(ec, 1, index(ec, "\"") - 1);

	    vcpus=substr(vcpus, index(vcpus, ":") +1);
	    vcpus=substr(vcpus, 1, index(vcpus, "\"") - 1);
	    vmem=substr(vmem, index(vmem, ":") +1);
	    vmem=substr(vmem, 1, index(vmem, "\"") - 1);
	    vcw=substr(vcw, index(vcw, ":") +1);
	    vcw=substr(vcw, 1, index(vcw, "\"") - 1);
	    printf("%s,%s %s,%s,%s,%s,%s,%s,%s,%s,%s\n",
                pname, snapdate, snaptime, pnum, ptype, pmode, ec, vcpus, vmem, vcw, cmd);  
        }'
}

########################
# Main()
########################
BASEDIR=$(dirname $0)	# This will get the directory this script resides in
#prints the column header
print "File, Location, Partition collected on, Time, Partition Number, Type, Mode, Entitled Capacity, Online Virtual CPUs, Online Memory, Variable Capacity Weight, Command Used\n"
host_name=$(/usr/bin/hostname -s)	
mkdir -p $BASEDIR/repository/nmon
find $BASEDIR/repository/nmon/ -type l | while read nmonfile
do    	
	if [[ -f "$nmonfile" ]] then # If file exists
		out=`cat $nmonfile | getnmoninfo`
		deref=`ls -l $nmonfile | awk '{print $11}`
		printf "%s,%s,%s\n" "$deref" "$host_name" "$out" 
	else
		rm $nmonfile
	fi
done