#!/bin/ksh93
#########################################################################################################
# iDoctor VIOS Investigator
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2000, 2012 All Rights Reserved.
#########################################################################################################
# This script will collect general information about a set of npiv collections 
# All npiv collections found on the system are the symbolic links residing in directory is /tmp/idoctor/npiv
# In order for a npiv collection to be visible to iDoctor a symbolic link must be created using commands like:
# 	 cd /tmp/idoctor/npiv
#        ln -s /tmp/npiv/npivdata.npiv npivdata.npiv

# parses data from the npiv file
getnpivinfo() {
    /usr/bin/awk ' {
          hostname=substr($0,1,255);
          ts=substr($0,256,26);
          nSnaps=substr($0,282,10);
          duration=substr($0,292,10);
          vfcListFile=substr($0,302,255);
          description=substr($0,557,50);
          gsub(/^[ \t]+|[ \t]+$nSnaps/, "", nSnaps); 
          gsub(/^[ \t]+|[ \t]+$duration/, "", duration); 
          gsub(/^[ \t]+|[ \t]+$hostname/, "", hostname); 
          gsub(/^[ \t]+|[ \t]+$description/, "", description);
          if (description == ".")   # handle the case of no description provided
               description="";
          printf("%s, %s, %s, %s, %s\n", hostname, ts, nSnaps, duration, description);  
       }        '

}

getcurinterval() {
    /usr/bin/awk 'BEGIN {FS=","} {print $1}' 
}


getmaxinterval() {
     /usr/bin/awk ' {
          nSnaps=substr($0,282,10);
          gsub(/^[ \t]+|[ \t]+$nSnaps/, "", nSnaps); 
          printf("%s", nSnaps);  
       }     '
}
	
########################
# Main()
########################
BASEDIR=$(dirname $0)	# This will get the directory this script resides in

#prints the column header
print "File, Percent complete, Location, Partition collected on, Time, Snapshots, Interval duration (seconds), Description\n"
host_name=$(/usr/bin/hostname -s)
mkdir -p $BASEDIR/repository/npiv
find $BASEDIR/repository/npiv/ -type l | while read npivfile
do    	
	if [[ -f "$npivfile" ]] then # If file exists
      	deref=`ls -l $npivfile | awk '{print $11}'`
            lines=`wc -l "$deref" | awk '{print $1}'`

            if [[ $lines -le 1 ]] then
		  printf "%s,0,%s\n" "$deref" "$host_name" 
            else      
	  	  out=`head -n 1 $npivfile | getnpivinfo`
              maxint=`head -n 1 $npivfile | getmaxinterval`
              curint=`tail -1 $npivfile | getcurinterval`                      
              pct=`echo "${curint}/${maxint}*100" | bc -l`
		  printf "%s,%.2f,%s,%s\n" "$deref" "$pct" "$host_name" "$out"
            fi
	else
		rm $npivfile
	fi
done
