#!/bin/ksh93
#########################################################################################################
# iDoctor VIOS Investigator
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2000, 2012 All Rights Reserved.
#########################################################################################################
# This script will return the following information about the perfpmr installation.
# It does assume that this has been installed under /tmp/perfXX
# The following details are returned: hostname, directory (if installed), Installed build date, Available build date, AIX level
#
# The available build date is retrieved by accessing the ftp.software.ibm.com and the results of which are cached into a file 
# in the /tmp/perfXX directory.
#
# Parameters:
#  CHECKREMOTE:  Pass 0 or 1 if the date of the build on the remote website should be rechecked (slower.)

  
# parse out the version information line from perfpmr.sh
getperfpmrinfo() {
    awk '    
	/PERFPMRVER=/ { date=$2; }
        END {
          date=substr(date, 1, length(date)-1);  # removes the last single quote after the date
	    printf("%s\n", date);  
        }'
}

# gets the date from the ftp listing and convert it to a YYYY/MM/DD format (same format found in perfpmr.sh)
# NOTE: FTP will not list the year if its the same as the current year.  year will contain HH:MM instead (GUI will handle showing current date)
getbuilddate() {
    awk '    
      	/perf/ {month=$6; day=$7; year=$8;}
        END {

            pos=index(year, ":");

            if (month == "Jan")
                month="1";
            if (month == "Feb")
                month="2";
            if (month == "Mar")
                month="3";
            if (month == "Apr")
                month="4";
            if (month == "May")
                month="5";
            if (month == "Jun")
                month="6";
            if (month == "Jul")
                month="7";
            if (month == "Aug")
                month="8";
            if (month == "Sep")
                month="9";
            if (month == "Oct")
                month="10";
            if (month == "Nov")
                month="11";
            if (month == "Dec")
                month="12";

            printf("%s/%s/%s\n", year, month, day);
        }
      
     '
}

## store the possible PerfPMR versions
PERFPMRVERSIONS="32,41,42,43,433,51,52,53,61,71"

########################
# Main()
########################

BASEDIR=$(dirname $0)	# This will get the directory this script resides in
host_name=$(/usr/bin/hostname -s)
CHECKREMOTE=$1
#determine the OS level, and then see if PerfPMR is installed in /tmp/perfxxx directory
OLDIFS=$IFS
IFS=","
success=0
AIXLEVEL=$(oslevel | sed s/\\.//g)
AIXLEVEL=${AIXLEVEL:0:3}

  if [[ $AIXLEVEL -ne "433" ]] then
    AIXLEVEL=${AIXLEVEL:0:2}

    for LEVEL in $PERFPMRVERSIONS; do 
     if [[ $AIXLEVEL == $LEVEL ]] then
         success=1
         break; 
     fi
    done 
  fi

  IFS=$OLDIFS
  
  PERFPMRDIR="/tmp/perf"$AIXLEVEL
  PERFPMRDATEFILE=$PERFPMRDIR"/perfpmrremotebuilddate.txt"
  mkdir -p $PERFPMRDIR
  
  if [[ -f $PERFPMRDATEFILE && $CHECKREMOTE -eq 0 ]] then
     remotedate=`cat $PERFPMRDATEFILE`
  else
     remotedate=`$BASEDIR/getrmtftpdir.sh ftp.software.ibm.com /aix/tools/perftools/perfpmr/perf$AIXLEVEL | getbuilddate`
     echo $remotedate > $PERFPMRDATEFILE
  fi
  
  if [[ $success -eq 1 ]] then 
     
     # now check if the perfPMR script exists
     if [[ -f $PERFPMRDIR"/perfpmr.sh" ]] then
        # read the script to determine the build date and version installed
        localdate=`cat $PERFPMRDIR"/perfpmr.sh" | getperfpmrinfo`
    
        # returns the PerfPMR directory and the version information string from the script
  	  printf "%s,%s,%s,%s,%s\n" "$host_name" "$PERFPMRDIR" "$localdate" "$remotedate" "$AIXLEVEL"
     else
        success=0
     fi
  fi
 
  if [[ $success -eq 0 ]] then 
     remotedate=`$BASEDIR/getrmtftpdir.sh ftp.software.ibm.com /aix/tools/perftools/perfpmr/perf$AIXLEVEL | getbuilddate`
     printf "%s,%s,%s,%s,%s\n" "$host_name" "Not installed" "" "$remotedate" "$AIXLEVEL"
  fi
