#!/bin/ksh93
#########################################################################################################
# iDoctor VIOS Investigator
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2000, 2012 All Rights Reserved.
#########################################################################################################
# This script will collect NPIV/FCstat data for all devices
## Change to output errors to a log.

vfcList=vfcList.out # Save the name file the containing the VFC list.
## Jump to Main.

########################
# getFCStatInfoLong()
########################
getFCStatInfoLong() {
    /usr/bin/awk ' # Get the fields of interest.
        BEGIN { RS="" } # Parse by paragraph.
        /Device Type:/ { wwpn=substr($NF, 3) } # Get the wwpn.
        /Port Speed \(/ { pss=$14; pssu=$15; psr=$19; psru=$20 } # Get the supported and running port speeds and their units.
        /IP over FC Adapter Driver Information/ { ipdrc=$11; ipaec=$16 } # Get the IP over FC Adapter Driver information.
        /FC SCSI Adapter Driver Information/ { drc=$10; aec=$15; crc=$20 } # Get the FC SCSI Adapter Driver information.
        /IP over FC Traffic Statistics/ { ipir=$8; ipor=$11; ipcr=$14; ipib=$17; ipob=$20 } # Get the IP over FC Traffic statistics.
        /FC SCSI Traffic Statistics/ { ir=$7; or=$10; cr=$13; ib=$16; ob=$19 } # Get the FC SCSI Traffic statistics.
        END {
            printf("%s,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%d,%s,%d,%s\n",
            	wwpn, ir, or, cr, ib, ob, drc, aec, crc, ipir, ipor, ipcr, ipib, ipob, ipdrc, ipaec, pss, pssu, psr, psru) # Output the fields.
        }'
}

########################
# getFCStatInfoShort()
########################
getFCStatInfoShort() {
    /usr/bin/awk ' # Get the fields of interest.
        BEGIN { RS="" } # Parse by paragraph.
        /FC SCSI Adapter Driver Information/ { drc=$10; aec=$15; crc=$20 } # Get the FC SCSI Adapter Driver information.
        /FC SCSI Traffic Statistics/ { ir=$7; or=$10; cr=$13; ib=$16; ob=$19 } # Get the FC SCSI Traffic statistics.
        END {
            printf("%d,%d,%d,%d,%d,%d,%d,%d\n",
                ir, or, cr, ib, ob, drc, aec, crc) # Output the fields.
        }'
}

########################
# Main()
########################
vfcList=$1 # Get the vfcList file name.
interval=$2 # Get the interval number.
duration=$3 # Get the duration.
if [[ $interval == "" ]] then # If an interval was not specified, 
	interval=1 # Set the interval to 1.
fi # End of If.
if [[ $duration == "" ]] then # If a duration was not specified,
	duration=0 # Set the duration to 0.
fi # Endo fo If.
hostname=$(/usr/bin/hostname -s) # Get the simple hostname of this system (not domain qualified).
#./getVfcList.sh $vfcList # Get a list of the FC devices with associated client partition names and wwpns.
timestamp=$(/usr/bin/date +"%Y-%m-%d-%H.%M.%S.000000") # Generate the timestamp.
/usr/bin/awk '{print $1}' $vfcList | # Get a list of all the FC devices found.
    /usr/bin/sort -u | # Sort and generate a list of unique FC device names.
        while read dev; do # While there are devices to handle,
            printf "%s,%s,%s,%s,<physical>,%s,%s\n" $interval $duration "$timestamp" $dev $hostname "$(/usr/sbin/fcstat $dev | getFCStatInfoLong)" # Get the FC statistics for the device.
            /usr/bin/grep -w "^$dev" $vfcList | # Get all the client records for this FC device.
                while read fc vfc host wwpn; do # While there are records to process,
                    fcstatout=$(/usr/sbin/fcstat -n $wwpn $dev) # fcstat the VFC
                    es=$? # Capture the exit status
                    if [[ $es -eq 0 ]] then # If the fcstat went okay,
                        print "$fcstatout" | printf "%s,%s,%s,%s,%s,%s,%s,%s\n" $interval $duration "$timestamp" $fc $vfc $host "$(getFCStatInfoLong)" # Get the FC statistics for the device.
                    else # fcstat failed in some way.
                        print -u2 "Error 'fcstat -n $wwpn $dev' for Host=$host, Device=$dev returned with ExitStatus=$es" # Report the problem to stderr. 
                    fi # End of If.
                done # End of While.
        done # End of While.
