#!/bin/ksh93
#########################################################################################################
# iDoctor VIOS Investigator
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2000, 2012 All Rights Reserved.
#########################################################################################################
# This script will collect general information about a set of PerfPMR collections 
# All PerfPMR collections found on the system are the symbolic links residing in directory is /tmp/idoctor/PerfPMR
# In order for a PerfPMR collection to be visible to idoctor a symbolic link must be created using commands like:
# 	 cd /tmp/idoctor/perfpmr
#        ln -fs /tmp/perfdata1 perfdata1
#

# parses data from lparstat.sum
getlparstat() {
    /usr/bin/awk ' 
	/Time before run:/ {snaptime=$0 }   
        /Partition Name/ { pname=$NF} 
        /Partition Number/ { pnum=$NF} 
        /Type/ { ptype=$NF} 
        /Mode                                       :/ { pmode=$NF} 
        /Entitled Capacity                          :/ { ec=$NF} 
        /Online Virtual CPUs/ { vcpus=$NF} 
        /Online Memory/ { vmem=$4; vmemunits=$NF} 
        /Variable Capacity Weight/ { vcw=$NF} 
        END {
	    snaptime=substr(snaptime, index(snaptime, ":") +1);
            printf("%s,%s,%d,%s,%s,%s,%d,%d %s,%d\n",
                pname, snaptime, pnum, ptype, pmode, ec, vcpus, vmem, vmemunits, vcw );  
        }'
}

# parses data from perfpmr.int
getperfpmrinfo() {
    /usr/bin/awk ' 
	/    PERFPMR: current directory:/ {curdir=$NF }   
	/    PERFPMR: perfpmr.sh Version/ {vrm=$4; vrmdate=$5}
	/    PERFPMR: perfpmr tool directory:/ { perfpmrdir=$NF }
	/    PERFPMR: Parameters passed to perfpmr.sh:/ { perfpmrparms=$NF }
        END {
	    printf("%s,%s,%s,%s,%s\n",
                curdir, vrm, vrmdate, perfpmrdir, perfpmrparms);  
        }'
}

	
########################
# Main()
########################
BASEDIR=$(dirname $0)	# This will get the directory this script resides in

#prints the column header
print "Directory, Location, Partition collected on, Time, Partition Number, Type, Mode, Entitled Capacity, Online Virtual CPUs, Online Memory, Variable Capacity Weight, Data Directory, PerfPMR version, PerfPMR date, PerfPMR Directory, PerfPMR Parms\n"
host_name=$(/usr/bin/hostname -s)
mkdir -p $BASEDIR/repository/perfpmr
find $BASEDIR/repository/perfpmr/ -type l | while read datadir
do
	if [[ -d "$datadir" ]] then # If directory exists
		cd $datadir
		out=`cat lparstat.sum | getlparstat`
		out2=`cat perfpmr.int | getperfpmrinfo`
            deref=`ls -l $datadir | awk '{print $11}`
		printf "%s,%s,%s,%s\n" "$deref" "$host_name" "$out" "$out2"
	else
		rm $datadir
	fi
done