#!/bin/ksh
#(C) Copyright IBM Corp. 2015
# iDoctor nmon Monitor
# This script will continuously collect nmon data at some interval.
# It takes two input variables which are the nmon interval size 
# and collection length.  Example to start the nmon monitor with 
# interval size of 5 minutes (300 seconds) and collection length of 
# 1 hour )(60 minutes):  nmon_monitor.sh 300 60

# declare variables

typeset -i intervalsize
typeset -i collectionlength
typeset -i collectionseconds
intervalsize=$1      # 1st input interval size in seconds
collectionlength=$2  # 2nd input collection length in minutes 
directory="/tmp/vios_investigator/nmon"
scpdirectory="/tmp/vios_investigator/scpout_nmon"
datetime=0
let collectionseconds=$collectionlength*60

 
# Check to make sure input variables are in a valid range

if [ $intervalsize -lt 1 ] ; then 
  # Support interval size between 1 second and 3600 seconds (1 hour)
  echo "Please use an interval size between 1 and 3600 seconds" 
  exit 1 
fi 

if [ $intervalsize -gt 3600 ] ; then 
  # Support interval size between 1 second and 3600 seconds (1 hour)
  echo "Please use an interval size between 1 and 3600 seconds" 
  exit 1 
fi 

if [ $collectionlength -lt 1 ] ; then 
  # Support collection length between 1 and 1440 minutes (1 day)
  echo "Please use collection length between 1 and 1440 minutes"
  exit 1
fi

if [ $collectionlength -gt 1440 ] ; then 
  # Support collection length between 1 and 1440 minutes (1 day)
  echo "Please use collection length between 1 and 1440 minutes"
  exit 1
fi

if [ $collectionseconds -lt intervalsize ] ; then 
  # Prevent Collection lengths that are shorter than the interval size  
  echo "Collection length must be equal to or greater than the interval size."
  exit 1 
fi

# Make sure the collection directory exists 
if [ ! -d "$directory" ]; then
  mkdir -p $directory
  chmod 777 $directory 
fi

# Make sure the scp output directory exists 
if [ ! -d "$scpdirectory" ]; then 
  mkdir -p $scpdirectory
  chmod 777 $scpdirectory 
fi
  
echo changing to data directory
cd $directory 

# Output of topas_nmon goes to current directory 
# Start nmon 
echo starting nmon 
topas_nmon -f -s $intervalsize -c $collectionlength -t -I 0.1 -d

# Build list of nmon files to transfer
# We'll transfer all nmon files in the current directory
# Sleep for a second to give nmon time to start
sleep 1
# Get the date and time for our file list
datetime=$(date +%y%m%d_%H%M%S)
# Build the list
ls | grep nmon > NmonFileList_$datetime                   																		   										
         
# Delay until nmon completes plus 10 seconds to ensure the file is closed
echo dely until nmon completes
typeset -i delaytime
sleep $collectionseconds
sleep 10

# Move nmon files 

#Make sure we're using the correct file list
file="NmonFileList_"$datetime
# Read the file one line at a time and transfer all the nmon files
# This ensures that if any nmon files failed to transfer previously 
# that they will be moved now.  
while read line
  do
	 nmonfile=$(echo $line)
	 echo moving "$nmonfile" to $scpdirectory
	 mv $directory/"$nmonfile" $scpdirectory

  done <"$file"
  
  rm NmonFileList_$datetime








