#!/bin/ksh
#########################################################################################################
# iDoctor VIOS Investigator
# Licensed Materials - Property of IBM
# (C) Copyright IBM Corp. 2000, 2012 All Rights Reserved.
#########################################################################################################

# iDoctor npiv Monitor
# This script will continuously collect npiv data at some interval.
# It takes two input variables which are the nmon interval size 
# and collection length (#of snapshots).  Example to start the npiv monitor with 
# collection length of 60 minutes (13 snapshots of 300 seconds)and interval size  
# of 300 seconds:  npiv_monitor.sh 13 300 

# declare variables

typeset -i intervalsize
typeset -i collectionlength
typeset -i collectionseconds
collectionlength=$1          # Number of snapshots 
intervalsize=$2              # Interval length in seconds
directory="/tmp/vios_investigator/npiv"
scpdirectory="/tmp/vios_investigator/scpout_npiv"
datetime=0
let collectionseconds=$collectionlength*$intervalsize

# Make sure the collection directory exists 
if [ ! -d "$directory" ]; then
  mkdir -p $directory
  chmod 777 $directory 
fi

# Make sure the scp output directory exists 
if [ ! -d "$scpdirectory" ]; then 
  mkdir -p $scpdirectory
  chmod 777 $scpdirectory 
fi
  
echo changing to data directory
cd $directory

# Output of startnpiv.sh goes to directory specified on the command
# Start npiv 
echo starting npiv collection 

nohup /tmp/idoctor/startnpiv.sh -1 $collectionlength $intervalsize 'cd /tmp/vios_investigatornpiv/' ''  > startnpiv.out 2> startnpiv.err < /dev/null &

# Build list of npiv files to transfer
# We'll transfer all npiv files in the current directory
# Sleep for a second to give npiv time to start
sleep 1
# Get the date and time for our file list
datetime=$(date +%y%m%d_%H%M%S)
# Build the list of npiv files
ls | grep $hostname"_" > NpivFileList_$datetime                   																		   										
         
# Delay until the npiv collection completes plus 10 seconds to give the file time to close
echo dely until npiv completes
typeset -i delaytime
sleep $collectionseconds
sleep 10

# Move npiv files 

# Make sure we're using the correct file list
file="NpivFileList_"$datetime
# Read the file one line at a time and transfer all the npiv files
# This ensures that if any npiv files failed to transfer previously 
# that they will be moved now.  
while read line
  do
	 npivfile=$(echo $line)
	 echo moving "$npivfile" to $scpdirectory
	 mv $directory/"$npivfile" $scpdirectory

  done <"$file"

# We're done, so remove the file list   
  rm NpivFileList_$datetime

